@@ -229,9 +229,16 @@ def cli_qa_update_quota(obj):
 
 @qa.command("list", help="List QA envs for user: all to show qa of all users.")
 @click.option("-u", "--user", "user", required=False)
+@click.option("-s", "--status", "status", multiple=True, type=str)
 @click.pass_obj
-def cli_qa_list(obj, user):
-    QA("list", obj["project"], obj["config"], obj["tokens"], user).run()
+def cli_qa_list(obj, user, status):
+    QA(
+        "list",
+        obj["project"],
+        obj["config"],
+        obj["tokens"],
+        {"user": user, "status": status},
+    ).run()
 
 
 @qa.command("create", help="Create QA env")
